@@ -173,7 +173,8 @@ class StaticTypeMismatch(ValidationError):
         elif str(self.actual).replace("?", "") == str(self.expected):
             msg += (
                 " -- to coerce T? X into T, try select_first([X,defaultValue])"
-                " or select_first([X]) (which might fail at runtime)"
+                " or select_first([X]) (which might fail at runtime);"
+                " to coerce Array[T?] X into Array[T], try select_all(X)"
             )
         return msg
 
@@ -184,10 +185,12 @@ class IncompatibleOperand(ValidationError):
 
 
 class UnknownIdentifier(ValidationError):
-    def __init__(self, node: SourceNode) -> None:
+    def __init__(self, node: SourceNode, message: Optional[str] = None) -> None:
         # avoiding circular dep:
         # assert isinstance(node, WDL.Expr.Ident)
-        super().__init__(node, "Unknown identifier " + str(node))
+        if not message:
+            message = "Unknown identifier " + str(node)
+        super().__init__(node, message)
 
 
 class NoSuchInput(ValidationError):
