@@ -192,7 +192,8 @@ class TestStdLib(unittest.TestCase):
                 Array[Int] bogus = select_first([one])
             }
         }
-        """, expected_exception=WDL.Error.NullValue)
+        """, expected_exception=WDL.Error.EvalError)
+        self.assertTrue("given empty or all-null array" in str(outputs))
         outputs = self._test_task(R"""
         version 1.0
         task test_select {
